Listeners — hermes 0.1 documentation

# Listeners

class `hermes.listeners.` `PostgresNotificationListener`(pg_connector, notif_channel, notif_queue, error_strategy, error_queue, fire_on_start=True)

  Bases: `hermes.components.Component`

  A listener to detect event notifications from Postgres and pass onto to a processor.

  Parameters: | pg_connector – A `PostgresConnector` object notif_channel – The string representing the notification channel to listen to updates on notif_queue – A `Queue` to be used for notification events. error_strategy – A `CommonErrorStrategy` subclass error_queue – A `Queue` to be used for error events.